package com.ruoyi.bst.articleCategory.service.impl;

import java.util.List;

import com.ruoyi.bst.device.utils.DeviceUtil;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.common.utils.ServiceUtil;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.bst.articleCategory.mapper.ArticleCategoryMapper;
import com.ruoyi.bst.articleCategory.domain.ArticleCategory;
import com.ruoyi.bst.articleCategory.domain.ArticleCategoryVO;
import com.ruoyi.bst.articleCategory.domain.ArticleCategoryQuery;
import com.ruoyi.bst.articleCategory.service.ArticleCategoryService;

/**
 * 文章分类Service业务层处理
 *
 * @author ruoyi
 * @date 2025-03-27
 */
@Service
public class ArticleCategoryServiceImpl implements ArticleCategoryService
{
    @Autowired
    private ArticleCategoryMapper articleCategoryMapper;

    /**
     * 查询文章分类
     *
     * @param id 文章分类主键
     * @return 文章分类
     */
    @Override
    public ArticleCategoryVO selectArticleCategoryById(Long id)
    {
        return articleCategoryMapper.selectArticleCategoryById(id);
    }

    /**
     * 查询文章分类列表
     *
     * @param articleCategoryQuery 文章分类
     * @return 文章分类
     */
    @Override
    public List<ArticleCategoryVO> selectArticleCategoryList(ArticleCategoryQuery articleCategoryQuery)
    {
        return articleCategoryMapper.selectArticleCategoryList(articleCategoryQuery);
    }

    /**
     * 新增文章分类
     *
     * @param articleCategory 文章分类
     * @return 结果
     */
    @Override
    public int insertArticleCategory(ArticleCategory articleCategory)
    {
        //同一分类下，分类名不允许重复
        Boolean flag = articleCategoryMapper.checkByNameAndParetId(articleCategory);
        if (flag){
            ServiceUtil.assertion(true,"不允许插入重复分类");
        }
        articleCategory.setCreateTime(DateUtils.getNowDate());
        return articleCategoryMapper.insertArticleCategory(articleCategory);
    }

    /**
     * 修改文章分类
     *
     * @param articleCategory 文章分类
     * @return 结果
     */
    @Override
    public int updateArticleCategory(ArticleCategory articleCategory)
    {
        //修改的目标分类不允许子分类重名
        Boolean flag = articleCategoryMapper.checkByNameAndParetId(articleCategory);
        if (flag){
            ServiceUtil.assertion(true,"目标分类下已经存在相同名称的分类");
        }
        return articleCategoryMapper.updateArticleCategory(articleCategory);
    }

    /**
     * 批量删除文章分类
     *
     * @param ids 需要删除的文章分类主键
     * @return 结果
     */
    @Override
    public int deleteArticleCategoryByIds(Long[] ids)
    {
        List<Long> cids = articleCategoryMapper.selectChildren(ids);
        if (cids.size() > 0){
            //当前分类如果有子分类，先删除子分类
            cids.forEach(this::deleteArticleCategoryById);
        }
        return articleCategoryMapper.deleteArticleCategoryByIds(ids);
    }

    /**
     * 删除文章分类信息
     *
     * @param id 文章分类主键
     * @return 结果
     */
    @Override
    public int deleteArticleCategoryById(Long id)
    {
        return articleCategoryMapper.deleteArticleCategoryById(id);
    }
}
